@@ -266,13 +266,13 @@ cleanup_hdr:
 	if (fd_hdr >= 0) {
 		close(fd_hdr);
 	}
-	if (rb && (flags & QB_RB_FLAG_CREATE)) {
+	if (rb && (rb->shared_hdr != MAP_FAILED) && (flags & QB_RB_FLAG_CREATE)) {
 		unlink(rb->shared_hdr->hdr_path);
 		if (rb->notifier.destroy_fn) {
 			(void)rb->notifier.destroy_fn(rb->notifier.instance);
 		}
 	}
-	if (rb && (rb->shared_hdr != MAP_FAILED && rb->shared_hdr != NULL)) {
+	if (rb && (rb->shared_hdr != MAP_FAILED)) {
 		munmap(rb->shared_hdr, sizeof(struct qb_ringbuffer_shared_s));
 	}
 	free(rb);
@@ -422,8 +422,7 @@ qb_rb_chunk_alloc(struct qb_ringbuffer_s * rb, size_t len)
 		while (qb_rb_space_free(rb) < (len + QB_RB_CHUNK_MARGIN)) {
 			int rc = _rb_chunk_reclaim(rb);
 			if (rc != 0) {
-				errno = rc;
-				return NULL;
+				return NULL;  /* errno already set */
 			}
 		}
 	} else {
@@ -542,7 +541,8 @@ _rb_chunk_reclaim(struct qb_ringbuffer_s * rb)
 	old_read_pt = rb->shared_hdr->read_pt;
 	chunk_magic = QB_RB_CHUNK_MAGIC_GET(rb, old_read_pt);
 	if (chunk_magic != QB_RB_CHUNK_MAGIC) {
-		return -EINVAL;
+		errno = EINVAL;
+		return -errno;
 	}
 
 	old_chunk_size = QB_RB_CHUNK_SIZE_GET(rb, old_read_pt);
